@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -23,7 +23,7 @@ class FilterActionPlaySoundTest : public QObject
 {
     Q_OBJECT
 public:
-    explicit FilterActionPlaySoundTest(QObject *parent = Q_NULLPTR);
+    explicit FilterActionPlaySoundTest(QObject *parent = nullptr);
     ~FilterActionPlaySoundTest();
 private Q_SLOTS:
     void shouldBeValid();
