@@ -23,7 +23,6 @@ using MailCommon::RuleWidgetHandlerManager;
 #include "mailcommon_debug.h"
 #include <PimCommon/MinimumComboBox>
 
-#include <QDialog>
 #include <KLocalizedString>
 #include <QPushButton>
 #include <KLineEdit>
@@ -34,7 +33,6 @@ using MailCommon::RuleWidgetHandlerManager;
 #include <QHBoxLayout>
 #include <QRadioButton>
 #include <QStackedWidget>
-#include <KConfigGroup>
 
 // Definition of special rule field strings
 // Note: Also see SearchRule::matches() and ruleFieldToEnglish() if
@@ -73,7 +71,8 @@ static const struct {
     { "CC", I18N_NOOP("CC")  },
     { "Reply-To", I18N_NOOP("Reply To")  },
     { "Organization", I18N_NOOP("Organization")  },
-    { "<date>", I18N_NOOP("Date")  }
+    { "<date>", I18N_NOOP("Date")  },
+    { "<encryption>", I18N_NOOP("Encryption") }
 };
 static const int SpecialRuleFieldsCount
     = sizeof(SpecialRuleFields) / sizeof(*SpecialRuleFields);
@@ -199,15 +198,15 @@ void SearchRuleWidget::initWidget(SearchPatternEdit::SearchModeType modeType)
     mRemove->setSizePolicy(QSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed));
     hlay->addWidget(mRemove);
 
-    RuleWidgetHandlerManager::instance()->setIsBalooSearch(modeType == SearchPatternEdit::BalooMode);
+    RuleWidgetHandlerManager::instance()->setIsAkonadiSearch(modeType == SearchPatternEdit::BalooMode);
 
     RuleWidgetHandlerManager::instance()->createWidgets(mFunctionStack, mValueStack, this);
 
     // redirect focus to the header field combo box
     setFocusProxy(mRuleField);
 
-    connect(mRuleField, SIGNAL(activated(QString)),
-            this, SLOT(slotRuleFieldChanged(QString)));
+    connect(mRuleField, QOverload<const QString &>::of(&KComboBox::activated),
+            this, &SearchRuleWidget::slotRuleFieldChanged);
     connect(mRuleField, &QComboBox::editTextChanged,
             this, &SearchRuleWidget::slotRuleFieldChanged);
     connect(mRuleField, &QComboBox::editTextChanged,
@@ -393,6 +392,8 @@ void SearchRuleWidget::initFieldList(SearchPatternEdit::SearchPatternEditOptions
         mFilterFieldList.append(i18n(SpecialRuleFields[Date].displayName));
     }
 
+    mFilterFieldList.append(i18n(SpecialRuleFields[Encryption].displayName));
+
     // these others only represent message headers and you can add to
     // them as you like
     mFilterFieldList.append(QStringLiteral("List-Id"));
@@ -416,7 +417,7 @@ void SearchRuleWidget::slotRuleFieldChanged(const QString &field)
 //=============================================================================
 
 SearchRuleWidgetLister::SearchRuleWidgetLister(QWidget *parent, SearchPatternEdit::SearchPatternEditOptions options, SearchPatternEdit::SearchModeType modeType)
-    : KWidgetLister(false, 2, SearchPattern::filterRulesMaximumSize(), parent)
+    : KWidgetLister(false, 1, SearchPattern::filterRulesMaximumSize(), parent)
 {
     mRuleList = nullptr;
 
@@ -641,8 +642,8 @@ void SearchPatternEdit::initLayout(SearchPatternEditOptions options, SearchModeT
     }
 
     //------------connect a few signals
-    connect(bg, SIGNAL(buttonClicked(QAbstractButton *)),
-            this, SLOT(slotRadioClicked(QAbstractButton *)));
+    connect(bg, QOverload<QAbstractButton *>::of(&QButtonGroup::buttonClicked),
+            this, &SearchPatternEdit::slotRadioClicked);
 
     //------------the list of SearchRuleWidget's
     mRuleLister
@@ -666,9 +667,9 @@ void SearchPatternEdit::initLayout(SearchPatternEditOptions options, SearchModeT
         qCDebug(MAILCOMMON_LOG) << "No first SearchRuleWidget, though slotClear() has been called!";
     }
 
-    connect(mRuleLister, SIGNAL(widgetAdded(QWidget *)),
-            this, SLOT(slotRuleAdded(QWidget *)));
-    connect(mRuleLister, SIGNAL(widgetRemoved()), this, SIGNAL(patternChanged()));
+    connect(mRuleLister, QOverload<QWidget *>::of(&SearchRuleWidgetLister::widgetAdded),
+            this, &SearchPatternEdit::slotRuleAdded);
+    connect(mRuleLister, QOverload<>::of(&SearchRuleWidgetLister::widgetRemoved), this, &SearchPatternEdit::patternChanged);
     connect(mRuleLister, &KPIM::KWidgetLister::clearWidgets, this, &SearchPatternEdit::patternChanged);
 
     layout->addWidget(mRuleLister);
