@@ -35,9 +35,7 @@ using MailCommon::FilterLog;
 #include <boost/bind.hpp>
 
 using namespace MailCommon;
-SearchRuleString::SearchRuleString(const QByteArray &field,
-                                   Function func,
-                                   const QString &contents)
+SearchRuleString::SearchRuleString(const QByteArray &field, Function func, const QString &contents)
     : SearchRule(field, func, contents)
 {
 }
@@ -73,23 +71,23 @@ SearchRule::RequiredPart SearchRuleString::requiredPart() const
 {
     const QByteArray f = field();
     SearchRule::RequiredPart part = Header;
-    if (qstricmp(f, "<recipients>") == 0 ||
-            qstricmp(f, "<status>") == 0 ||
-            qstricmp(f, "<tag>") == 0 ||
-            qstricmp(f, "subject") == 0 ||
-            qstricmp(f, "from") == 0 ||
-            qstricmp(f, "sender") == 0 ||
-            qstricmp(f, "reply-to") == 0 ||
-            qstricmp(f, "to") == 0  ||
-            qstricmp(f, "cc") == 0 ||
-            qstricmp(f, "bcc") == 0 ||
-            qstricmp(f, "in-reply-to") == 0 ||
-            qstricmp(f, "message-id") == 0 ||
-            qstricmp(f, "references") == 0) {
+    if (qstricmp(f.constData(), "<recipients>") == 0
+        || qstricmp(f.constData(), "<status>") == 0
+        || qstricmp(f.constData(), "<tag>") == 0
+        || qstricmp(f.constData(), "subject") == 0
+        || qstricmp(f.constData(), "from") == 0
+        || qstricmp(f.constData(), "sender") == 0
+        || qstricmp(f.constData(), "reply-to") == 0
+        || qstricmp(f.constData(), "to") == 0
+        || qstricmp(f.constData(), "cc") == 0
+        || qstricmp(f.constData(), "bcc") == 0
+        || qstricmp(f.constData(), "in-reply-to") == 0
+        || qstricmp(f.constData(), "message-id") == 0
+        || qstricmp(f.constData(), "references") == 0) {
         // these fields are directly provided by KMime::Message, no need to fetch the whole Header part
         part = Envelope;
-    } else if (qstricmp(f, "<message>") == 0 ||
-               qstricmp(f, "<body>") == 0) {
+    } else if (qstricmp(f.constData(), "<message>") == 0
+               || qstricmp(f.constData(), "<body>") == 0) {
         part = CompleteMessage;
     }
 
@@ -117,16 +115,16 @@ bool SearchRuleString::matches(const Akonadi::Item &item) const
     // Overwrite the value for complete messages and all headers!
     bool logContents = true;
 
-    if (qstricmp(field(), "<message>") == 0) {
-        msgContents = msg->encodedContent();
+    if (qstricmp(field().constData(), "<message>") == 0) {
+        msgContents = QString::fromUtf8(msg->encodedContent());
         logContents = false;
-    } else if (qstricmp(field(), "<body>") == 0) {
-        msgContents = msg->body();
+    } else if (qstricmp(field().constData(), "<body>") == 0) {
+        msgContents = QString::fromUtf8(msg->body());
         logContents = false;
-    } else if (qstricmp(field(), "<any header>") == 0) {
-        msgContents = msg->head();
+    } else if (qstricmp(field().constData(), "<any header>") == 0) {
+        msgContents = QString::fromUtf8(msg->head());
         logContents = false;
-    } else if (qstricmp(field(), "<recipients>") == 0) {
+    } else if (qstricmp(field().constData(), "<recipients>") == 0) {
         // (mmutz 2001-11-05) hack to fix "<recipients> !contains foo" to
         // meet user's expectations. See FAQ entry in KDE 2.2.2's KMail
         // handbook
@@ -134,14 +132,14 @@ bool SearchRuleString::matches(const Akonadi::Item &item) const
             // do we need to treat this case specially? Ie.: What shall
             // "equality" mean for recipients.
             return
-                matchesInternal(msg->to()->asUnicodeString()) ||
-                matchesInternal(msg->cc()->asUnicodeString()) ||
-                matchesInternal(msg->bcc()->asUnicodeString());
+                matchesInternal(msg->to()->asUnicodeString())
+                || matchesInternal(msg->cc()->asUnicodeString())
+                || matchesInternal(msg->bcc()->asUnicodeString());
         }
         msgContents = msg->to()->asUnicodeString();
         msgContents += ", " + msg->cc()->asUnicodeString();
         msgContents += ", " + msg->bcc()->asUnicodeString();
-    } else if (qstricmp(field(), "<tag>") == 0) {
+    } else if (qstricmp(field().constData(), "<tag>") == 0) {
         //port?
         //     const Nepomuk2::Resource res( item.url() );
         //     foreach ( const Nepomuk2::Tag &tag, res.tags() ) {
@@ -151,17 +149,17 @@ bool SearchRuleString::matches(const Akonadi::Item &item) const
     } else {
         // make sure to treat messages with multiple header lines for
         // the same header correctly
-        msgContents = "";
-        if (auto hrd = msg->headerByType(field())) {
+        msgContents = QStringLiteral("");
+        if (auto hrd = msg->headerByType(field().constData())) {
             msgContents = hrd->asUnicodeString();
         }
     }
 
-    if (function() == FuncIsInAddressbook ||
-            function() == FuncIsNotInAddressbook) {
+    if (function() == FuncIsInAddressbook
+        || function() == FuncIsNotInAddressbook) {
         // I think only the "from"-field makes sense.
-        msgContents = "";
-        if (auto hrd = msg->headerByType(field())) {
+        msgContents = QStringLiteral("");
+        if (auto hrd = msg->headerByType(field().constData())) {
             msgContents = hrd->asUnicodeString();
         }
 
@@ -179,11 +177,11 @@ bool SearchRuleString::matches(const Akonadi::Item &item) const
 
     bool rc = matchesInternal(msgContents);
     if (FilterLog::instance()->isLogging()) {
-        QString msg = (rc ? "<font color=#00FF00>1 = </font>" : "<font color=#FF0000>0 = </font>");
+        QString msg = (rc ? QStringLiteral("<font color=#00FF00>1 = </font>") : QStringLiteral("<font color=#FF0000>0 = </font>"));
         msg += FilterLog::recode(asString());
         // only log headers bcause messages and bodies can be pretty large
         if (logContents) {
-            msg += " (<i>" + FilterLog::recode(msgContents) + "</i>)";
+            msg += QStringLiteral(" (<i>") + FilterLog::recode(msgContents) + QStringLiteral("</i>)");
         }
         FilterLog::instance()->add(msg, FilterLog::RuleResult);
     }
@@ -195,43 +193,43 @@ void SearchRuleString::addQueryTerms(Akonadi::SearchTerm &groupTerm, bool &empty
     using namespace Akonadi;
     emptyIsNotAnError = false;
     SearchTerm termGroup(SearchTerm::RelOr);
-    if (qstricmp(field(), "subject") == 0) {
+    if (qstricmp(field().constData(), "subject") == 0) {
         termGroup.addSubTerm(EmailSearchTerm(EmailSearchTerm::Subject, contents(), akonadiComparator()));
-    } else if (qstricmp(field(), "reply-to") == 0) {
+    } else if (qstricmp(field().constData(), "reply-to") == 0) {
         termGroup.addSubTerm(EmailSearchTerm(EmailSearchTerm::HeaderReplyTo, contents(), akonadiComparator()));
-    } else if (qstricmp(field(), "<message>") == 0) {
+    } else if (qstricmp(field().constData(), "<message>") == 0) {
         termGroup.addSubTerm(EmailSearchTerm(EmailSearchTerm::Message, contents(), akonadiComparator()));
     } else if (field() == "<body>") {
         termGroup.addSubTerm(EmailSearchTerm(EmailSearchTerm::Body, contents(), akonadiComparator()));
         termGroup.addSubTerm(EmailSearchTerm(EmailSearchTerm::Attachment, contents(), akonadiComparator()));
-    } else if (qstricmp(field(), "<recipients>") == 0) {
+    } else if (qstricmp(field().constData(), "<recipients>") == 0) {
         termGroup.addSubTerm(EmailSearchTerm(EmailSearchTerm::HeaderTo, contents(), akonadiComparator()));
         termGroup.addSubTerm(EmailSearchTerm(EmailSearchTerm::HeaderCC, contents(), akonadiComparator()));
         termGroup.addSubTerm(EmailSearchTerm(EmailSearchTerm::HeaderBCC, contents(), akonadiComparator()));
-    } else if (qstricmp(field(), "<any header>") == 0) {
+    } else if (qstricmp(field().constData(), "<any header>") == 0) {
         termGroup.addSubTerm(EmailSearchTerm(EmailSearchTerm::Headers, contents(), akonadiComparator()));
         termGroup.addSubTerm(EmailSearchTerm(EmailSearchTerm::Subject, contents(), akonadiComparator()));
-    } else if (qstricmp(field(), "to") == 0) {
+    } else if (qstricmp(field().constData(), "to") == 0) {
         termGroup.addSubTerm(EmailSearchTerm(EmailSearchTerm::HeaderTo, contents(), akonadiComparator()));
-    } else if (qstricmp(field(), "cc") == 0) {
+    } else if (qstricmp(field().constData(), "cc") == 0) {
         termGroup.addSubTerm(EmailSearchTerm(EmailSearchTerm::HeaderCC, contents(), akonadiComparator()));
-    } else if (qstricmp(field(), "bcc") == 0) {
+    } else if (qstricmp(field().constData(), "bcc") == 0) {
         termGroup.addSubTerm(EmailSearchTerm(EmailSearchTerm::HeaderBCC, contents(), akonadiComparator()));
-    } else if (qstricmp(field(), "from") == 0) {
+    } else if (qstricmp(field().constData(), "from") == 0) {
         termGroup.addSubTerm(EmailSearchTerm(EmailSearchTerm::HeaderFrom, contents(), akonadiComparator()));
-    } else if (qstricmp(field(), "list-id") == 0) {
+    } else if (qstricmp(field().constData(), "list-id") == 0) {
         termGroup.addSubTerm(EmailSearchTerm(EmailSearchTerm::HeaderListId, contents(), akonadiComparator()));
-    } else if (qstricmp(field(), "resent-from") == 0) {
+    } else if (qstricmp(field().constData(), "resent-from") == 0) {
         termGroup.addSubTerm(EmailSearchTerm(EmailSearchTerm::HeaderResentFrom, contents(), akonadiComparator()));
-    } else if (qstricmp(field(), "x-loop") == 0) {
+    } else if (qstricmp(field().constData(), "x-loop") == 0) {
         termGroup.addSubTerm(EmailSearchTerm(EmailSearchTerm::HeaderXLoop, contents(), akonadiComparator()));
-    } else if (qstricmp(field(), "x-mailing-list") == 0) {
+    } else if (qstricmp(field().constData(), "x-mailing-list") == 0) {
         termGroup.addSubTerm(EmailSearchTerm(EmailSearchTerm::HeaderXMailingList, contents(), akonadiComparator()));
-    } else if (qstricmp(field(), "x-spam-flag") == 0) {
+    } else if (qstricmp(field().constData(), "x-spam-flag") == 0) {
         termGroup.addSubTerm(EmailSearchTerm(EmailSearchTerm::HeaderXSpamFlag, contents(), akonadiComparator()));
-    } else if (qstricmp(field(), "organization")  == 0) {
+    } else if (qstricmp(field().constData(), "organization") == 0) {
         termGroup.addSubTerm(EmailSearchTerm(EmailSearchTerm::HeaderOrganization, contents(), akonadiComparator()));
-    } else if (qstricmp(field(), "<tag>") == 0) {
+    } else if (qstricmp(field().constData(), "<tag>") == 0) {
         termGroup.addSubTerm(EmailSearchTerm(EmailSearchTerm::MessageTag, contents(), akonadiComparator()));
     }
 
@@ -257,56 +255,55 @@ bool SearchRuleString::matchesInternal(const QString &msgContents) const
 
     switch (function()) {
     case SearchRule::FuncEquals:
-        return (QString::compare(msgContents.toLower(), contents().toLower()) == 0);
+        return QString::compare(msgContents.toLower(), contents().toLower()) == 0;
 
     case SearchRule::FuncNotEqual:
-        return (QString::compare(msgContents.toLower(), contents().toLower()) != 0);
+        return QString::compare(msgContents.toLower(), contents().toLower()) != 0;
 
     case SearchRule::FuncContains:
-        return (msgContents.contains(contents(), Qt::CaseInsensitive));
+        return msgContents.contains(contents(), Qt::CaseInsensitive);
 
     case SearchRule::FuncContainsNot:
-        return (!msgContents.contains(contents(), Qt::CaseInsensitive));
+        return !msgContents.contains(contents(), Qt::CaseInsensitive);
 
-    case SearchRule::FuncRegExp: {
+    case SearchRule::FuncRegExp:
+    {
         QRegExp regexp(contents(), Qt::CaseInsensitive);
-        return (regexp.indexIn(msgContents) >= 0);
+        return regexp.indexIn(msgContents) >= 0;
     }
 
-    case SearchRule::FuncNotRegExp: {
+    case SearchRule::FuncNotRegExp:
+    {
         QRegExp regexp(contents(), Qt::CaseInsensitive);
-        return (regexp.indexIn(msgContents) < 0);
+        return regexp.indexIn(msgContents) < 0;
     }
 
-    case SearchRule::FuncStartWith: {
+    case SearchRule::FuncStartWith:
         return msgContents.startsWith(contents());
-    }
 
-    case SearchRule::FuncNotStartWith: {
+    case SearchRule::FuncNotStartWith:
         return !msgContents.startsWith(contents());
-    }
 
-    case SearchRule::FuncEndWith: {
+    case SearchRule::FuncEndWith:
         return msgContents.endsWith(contents());
-    }
 
-    case SearchRule::FuncNotEndWith: {
+    case SearchRule::FuncNotEndWith:
         return !msgContents.endsWith(contents());
-    }
 
     case FuncIsGreater:
-        return (QString::compare(msgContents.toLower(), contents().toLower()) > 0);
+        return QString::compare(msgContents.toLower(), contents().toLower()) > 0;
 
     case FuncIsLessOrEqual:
-        return (QString::compare(msgContents.toLower(), contents().toLower()) <= 0);
+        return QString::compare(msgContents.toLower(), contents().toLower()) <= 0;
 
     case FuncIsLess:
-        return (QString::compare(msgContents.toLower(), contents().toLower()) < 0);
+        return QString::compare(msgContents.toLower(), contents().toLower()) < 0;
 
     case FuncIsGreaterOrEqual:
-        return (QString::compare(msgContents.toLower(), contents().toLower()) >= 0);
+        return QString::compare(msgContents.toLower(), contents().toLower()) >= 0;
 
-    case FuncIsInAddressbook: {
+    case FuncIsInAddressbook:
+    {
         const QStringList addressList = KEmailAddress::splitAddressList(msgContents.toLower());
         QStringList::ConstIterator end(addressList.constEnd());
         for (QStringList::ConstIterator it = addressList.constBegin(); (it != end); ++it) {
@@ -325,7 +322,8 @@ bool SearchRuleString::matchesInternal(const QString &msgContents) const
         return false;
     }
 
-    case FuncIsNotInAddressbook: {
+    case FuncIsNotInAddressbook:
+    {
         const QStringList addressList = KEmailAddress::splitAddressList(msgContents.toLower());
         QStringList::ConstIterator end(addressList.constEnd());
 
@@ -345,9 +343,10 @@ bool SearchRuleString::matchesInternal(const QString &msgContents) const
         return false;
     }
 
-    case FuncIsInCategory: {
+    case FuncIsInCategory:
+    {
         QString category = contents();
-        const QStringList addressList =  KEmailAddress::splitAddressList(msgContents.toLower());
+        const QStringList addressList = KEmailAddress::splitAddressList(msgContents.toLower());
 
         QStringList::ConstIterator end(addressList.constEnd());
         for (QStringList::ConstIterator it = addressList.constBegin(); it != end; ++it) {
@@ -369,9 +368,10 @@ bool SearchRuleString::matchesInternal(const QString &msgContents) const
         return false;
     }
 
-    case FuncIsNotInCategory: {
+    case FuncIsNotInCategory:
+    {
         QString category = contents();
-        const QStringList addressList =  KEmailAddress::splitAddressList(msgContents.toLower());
+        const QStringList addressList = KEmailAddress::splitAddressList(msgContents.toLower());
 
         QStringList::ConstIterator end(addressList.constEnd());
         for (QStringList::ConstIterator it = addressList.constBegin(); it != end; ++it) {
@@ -389,7 +389,6 @@ bool SearchRuleString::matchesInternal(const QString &msgContents) const
                     }
                 }
             }
-
         }
         return true;
     }
